summaryrefslogtreecommitdiffstats
path: root/BaseTools/Source/Python/AutoGen/InfSectionParser.py
diff options
context:
space:
mode:
Diffstat (limited to 'BaseTools/Source/Python/AutoGen/InfSectionParser.py')
-rw-r--r--BaseTools/Source/Python/AutoGen/InfSectionParser.py10
1 files changed, 5 insertions, 5 deletions
diff --git a/BaseTools/Source/Python/AutoGen/InfSectionParser.py b/BaseTools/Source/Python/AutoGen/InfSectionParser.py
index 09e9af3fb4..388b6780df 100644
--- a/BaseTools/Source/Python/AutoGen/InfSectionParser.py
+++ b/BaseTools/Source/Python/AutoGen/InfSectionParser.py
@@ -80,13 +80,13 @@ class InfSectionParser():
UserExtensionTianoCore.append({SubSection: SectionDataDict[key]})
return UserExtensionTianoCore
# Get depex expresion
#
# @return: a list include some dictionary that key is section and value is a list contain all data.
def GetDepexExpresionList(self):
- DepexExpresionList = []
+ DepexExpressionList = []
if not self._FileSectionDataList:
- return DepexExpresionList
+ return DepexExpressionList
for SectionDataDict in self._FileSectionDataList:
for key in SectionDataDict:
if key.lower() == "[depex]" or key.lower().startswith("[depex."):
@@ -105,8 +105,8 @@ class InfSectionParser():
SubKey = (SectionList[1], SectionList[2])
else:
EdkLogger.error("build", AUTOGEN_ERROR, 'Section %s is invalid.' % key)
- DepexExpresionList.append({SubKey: SectionDataDict[key]})
- return DepexExpresionList
+ DepexExpressionList.append({SubKey: SectionDataDict[key]})
+ return DepexExpressionList
@@ -80,13 +80,13 @@ class InfSectionParser():
UserExtensionTianoCore.append({SubSection: SectionDataDict[key]})
return UserExtensionTianoCore
- # Get depex expresion
+ # Get depex expression
#
# @return: a list include some dictionary that key is section and value is a list contain all data.